km3modules\.common\.GetAngle
============================

.. currentmodule:: km3modules.common

.. autoclass:: GetAngle

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GetAngle.__init__
      ~GetAngle.add
      ~GetAngle.configure
      ~GetAngle.expose
      ~GetAngle.finish
      ~GetAngle.get
      ~GetAngle.pre_finish
      ~GetAngle.process
      ~GetAngle.require
   
   

   
   
   